#
# spec file for package libcfile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcfile
%define lname	libcfile1
Version:        20240414
Release:        1.2
Summary:        Library for C file functions
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libcfile
Source:         https://github.com/libyal/libcfile/releases/download/%version/%name-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libcfile/releases/download/%version/%name-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libuna) >= 20240130
# Various notes: https://en.opensuse.org/libyal

%description
A library and devel package for C file functions.

%package -n %lname
Summary:        Library for C file functions
Group:          System/Libraries

%description -n %lname
A library for C file functions. Part of the libyal library collection.

%package devel
Summary:        Development files for libcfile, a C file library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A library for C file functions.

This subpackage contains libraries and header files for developing
applications that want to make use of libcfile.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING.LESSER
%_libdir/libcfile.so.1*

%files devel
%_includedir/libcfile*
%_libdir/libcfile.so
%_libdir/pkgconfig/libcfile.pc
%_mandir/man3/libcfile.3*

%changelog
* Sun Apr 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240414
  * No changelog was provided
* Thu Mar 14 2024 Jan Engelhardt <jengelh@inai.de>
- Fix buildrequirement on libcfile
- Modernize %%post(un) section
* Sat Jan  6 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240106
  * No changelog was provided
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add signature and keyring
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220106
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210409 (1b077fb7)
  * No changelog was provided
- Add system-libs.patch
* Sun Dec 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200216
  * changes for block aligned read
  * Added O_CLOEXEC to open file IO flags
* Sat Apr 13 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190314
  * Added O_CLOEXEC to open file IO flags
  * Code cleanup
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170105
  * worked on tests
  * added remove file function
  * worked on fallback functions
  * remove stream functions
* Mon Jan  5 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to 0~20140624
  * code clean up
  * worked on non-blocking Windows device file support
  * worked on block-based read to support Windows device files
  * worked on dynamic late binding functions
  * small changes
  * Fix for devices that don't support fadvice
  * 2014 update
  * updated dependencies
* Tue Dec  3 2013 coolo@suse.com
- don't buildrequire ourselves
* Wed Oct 23 2013 Greg.Freemyer@gmail.com
- update to v0~20130809
  * bug fix for file access behavior
- update BuildRequires to use factory versions of packages when possible
* Mon Jul 29 2013 Greg.Freemyer@gmail.com
- update to v0~20130609
  * fix in .pc.in file
  * updated dependencies
  * removed WINAPI CRT function fallbacks
  * changes to ioctl detection in configure
  * textual changes
- change to gz compression to simplyfy download/convert step
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- add BuildRequires: libcnotify
- run spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20130329) for build.opensuse.org
